@@ -15,7 +15,7 @@ class SQLite(object):
                 cursor.execute(House.create_table())
                 print('database initialized')
 
-    def add_house(self, house:House):
+    def add_house(self, house:House) -> None:
         with sqlite3.connect(self.location) as conn:
             cursor = conn.cursor()
             house.insert(cursor)
\ No newline at end of file
